Module error

Module error 

Error type for migration operations.

Enums

Error
All the ways the lifecycle of applying migrations can end in failure.

Traits

DatabaseError
Converting a result with a generic std::error::Error to one with this crate’s error type.

Type Aliases

TernResult
Alias for a result whose error type is Error.