#[non_exhaustive]pub enum Error {
Execute(Box<dyn StdError + Send + Sync + 'static>),
ExecuteMigration(Box<dyn StdError + Send + Sync + 'static>, MigrationId, bool),
ResolveQuery(String),
Sql(Error),
Split(Error, usize),
MissingSource {
local: i64,
history: i64,
msg: String,
},
OutOfSync {
at_issue: Vec<MigrationId>,
msg: String,
},
Invalid(String),
Partial {
source: Box<dyn StdError + Send + Sync + 'static>,
report: Report,
},
}Expand description
All the ways the lifecycle of applying migrations can end in failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Execute(Box<dyn StdError + Send + Sync + 'static>)
An error that came from applying migrations.
ExecuteMigration(Box<dyn StdError + Send + Sync + 'static>, MigrationId, bool)
Error from one migration.
ResolveQuery(String)
An error resolving the query before applying.
Can be used as a fallthrough to map arbitrary error types to when
implementing QueryBuilder.
Sql(Error)
Error processing a migration source.
Split(Error, usize)
Error parsing a SQL source into statements.
MissingSource
Local migration source has fewer migrations than the history table.
OutOfSync
The source migrations and the history are not synchronized in a way that is expected.
Invalid(String)
The options passed are not valid.
Partial
An error occurred, resulting in a partial migration run.
Implementations