pub struct Query(/* private fields */);Expand description
A SQL query.
Implementations
Sourceimpl Query
impl Query
Sourcepub fn append(&mut self, other: Self) -> TernResult<()>
pub fn append(&mut self, other: Self) -> TernResult<()>
Add another query to the end of this one.
Sourcepub fn split_statements(&self) -> TernResult<Vec<String>>
pub fn split_statements(&self) -> TernResult<Vec<String>>
Split a query comprised of multiple statements into a collection of the atomic, single statements.
This is necessary to honor the contract of “tern:noTransaction”, since sending a query with multiple statements is treated as one prepared statement and ran in a transaction automatically.